@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.logger.ILogAction import ILogAction
-from src.providers.logger.ILogContext import ILogContext
+from nerualpha.providers.logger.ILogAction import ILogAction
+from nerualpha.providers.logger.ILogContext import ILogContext
 
 @dataclass
 class LogAction(ILogAction):
