@@ -15,19 +15,19 @@ from nerualpha.providers.logger.sourceTypes import SourceTypes
 @dataclass
 class Logger(ILogger):
     url: str
-    sessionId: str
+    session: ISession
     bridge: IBridge
     config: IConfig
     provider: str = field(default = "logs-submission")
     def __init__(self,session):
         self.config = session.config
         self.bridge = session.bridge
-        self.sessionId = session.id
+        self.session = session
         self.url = self.config.getExecutionUrl(self.provider)
     
     def createLogAction(self,level,message,context = None):
         logAction = LogAction()
-        logAction.id = self.sessionId
+        logAction.id = self.session.id
         logAction.api_application_id = self.config.apiApplicationId
         logAction.api_account_id = self.config.apiAccountId
         logAction.session_id = self.bridge.uuid()
@@ -51,6 +51,7 @@ class Logger(ILogger):
         requestParams.method = RequestMethods.POST
         requestParams.url = self.config.getExecutionUrl("logs-submission")
         requestParams.data = logAction
+        requestParams.headers = self.session.constructRequestHeaders()
         await self.bridge.requestWithoutResponse(requestParams)
     
     def reprJSON(self):
