@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.messages.contracts.IImagePayload import IImagePayload
-from src.providers.messages.contracts.IMMSVCardMessage import IMMSVCardMessage
+from nerualpha.providers.messages.contracts.IImagePayload import IImagePayload
+from nerualpha.providers.messages.contracts.IMMSVCardMessage import IMMSVCardMessage
 
 @dataclass
 class MMSVCardMessage(IMMSVCardMessage):
