@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.messages.contracts.ISMSMessage import ISMSMessage
+from nerualpha.providers.messages.contracts.ISMSMessage import ISMSMessage
 
 @dataclass
 class SMSMessage(ISMSMessage):
