@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IAcceptInboundCallEndpoint import IAcceptInboundCallEndpoint
-from src.providers.voice.contracts.ILegId import ILegId
+from nerualpha.providers.voice.contracts.IAcceptInboundCallEndpoint import IAcceptInboundCallEndpoint
+from nerualpha.providers.voice.contracts.ILegId import ILegId
 
 
 #interface
