@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IAcceptInboundCallBody import IAcceptInboundCallBody
-from src.providers.voice.contracts.IAcceptInboundCallEvent import IAcceptInboundCallEvent
+from nerualpha.providers.voice.contracts.IAcceptInboundCallBody import IAcceptInboundCallBody
+from nerualpha.providers.voice.contracts.IAcceptInboundCallEvent import IAcceptInboundCallEvent
 
 @dataclass
 class AcceptInboundCallEvent(IAcceptInboundCallEvent):
