@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IAcceptInboundCallChannel import IAcceptInboundCallChannel
-from src.providers.voice.contracts.IAcceptInboundCallResponse import IAcceptInboundCallResponse
-from src.providers.voice.contracts.ICallTimestamp import ICallTimestamp
+from nerualpha.providers.voice.contracts.IAcceptInboundCallChannel import IAcceptInboundCallChannel
+from nerualpha.providers.voice.contracts.IAcceptInboundCallResponse import IAcceptInboundCallResponse
+from nerualpha.providers.voice.contracts.ICallTimestamp import ICallTimestamp
 
 @dataclass
 class AcceptInboundCallResponse(IAcceptInboundCallResponse):
