@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.ICallTimestamp import ICallTimestamp
+from nerualpha.providers.voice.contracts.ICallTimestamp import ICallTimestamp
 
 @dataclass
 class CallTimestamp(ICallTimestamp):
