@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IEarmuffPayload import IEarmuffPayload
-from src.providers.voice.csEvents import CSEvents
+from nerualpha.providers.voice.contracts.IEarmuffPayload import IEarmuffPayload
+from nerualpha.providers.voice.csEvents import CSEvents
 
 @dataclass
 class EarmuffPayload(IEarmuffPayload):
