@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IAcceptInboundCallChannel import IAcceptInboundCallChannel
-from src.providers.voice.contracts.ICallTimestamp import ICallTimestamp
-from src.providers.voice.contracts.IInviteMemberResponse import IInviteMemberResponse
+from nerualpha.providers.voice.contracts.IAcceptInboundCallChannel import IAcceptInboundCallChannel
+from nerualpha.providers.voice.contracts.ICallTimestamp import ICallTimestamp
+from nerualpha.providers.voice.contracts.IInviteMemberResponse import IInviteMemberResponse
 
 @dataclass
 class InviteMemberResponse(IInviteMemberResponse):
