@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.ISayTextPayload import ISayTextPayload
-from src.providers.voice.csEvents import CSEvents
-from src.providers.voice.contracts.ISayTextBody import ISayTextBody
+from nerualpha.providers.voice.contracts.ISayTextPayload import ISayTextPayload
+from nerualpha.providers.voice.csEvents import CSEvents
+from nerualpha.providers.voice.contracts.ISayTextBody import ISayTextBody
 
 @dataclass
 class SayTextPayload(ISayTextPayload):
