@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IUser import IUser
+from nerualpha.providers.voice.contracts.IUser import IUser
 
 @dataclass
 class User(IUser):
