@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.request.IRequestHeaders import IRequestHeaders
+from nerualpha.request.IRequestHeaders import IRequestHeaders
 
 @dataclass
 class RequestHeaders(IRequestHeaders):
