@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.request.IRequestHeaders import IRequestHeaders
-from src.request.IRequestParams import IRequestParams
+from nerualpha.request.IRequestHeaders import IRequestHeaders
+from nerualpha.request.IRequestParams import IRequestParams
 
 T = TypeVar("T")
 
