@@ -2,15 +2,15 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.IBridge import IBridge
-from src.providers.logger.ILogContext import ILogContext
-from src.request.RequestHeaders import RequestHeaders
-from src.services.commandService.ICommandService import ICommandService
-from src.services.config.IConfig import IConfig
-from src.session.CommandHeaders import CommandHeaders
-from src.session.IActionPayload import IActionPayload
-from src.session.IFilter import IFilter
-from src.session.wrappedCallback import WrappedCallback
+from nerualpha.IBridge import IBridge
+from nerualpha.providers.logger.ILogContext import ILogContext
+from nerualpha.request.RequestHeaders import RequestHeaders
+from nerualpha.services.commandService.ICommandService import ICommandService
+from nerualpha.services.config.IConfig import IConfig
+from nerualpha.session.CommandHeaders import CommandHeaders
+from nerualpha.session.IActionPayload import IActionPayload
+from nerualpha.session.IFilter import IFilter
+from nerualpha.session.wrappedCallback import WrappedCallback
 
 
 #interface
