@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.IBaseEvent import IBaseEvent
+from nerualpha.webhookEvents.IBaseEvent import IBaseEvent
 
 @dataclass
 class BaseEvent(IBaseEvent):
