@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.sms.ISMSMetadata import ISMSMetadata
+from nerualpha.webhookEvents.sms.ISMSMetadata import ISMSMetadata
 
 @dataclass
 class SMSMetadata(ISMSMetadata):
