@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.IUrlObject import IUrlObject
+from nerualpha.webhookEvents.IUrlObject import IUrlObject
 
 @dataclass
 class UrlObject(IUrlObject):
