@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.whatsapp.IReplyObject import IReplyObject
-from src.webhookEvents.whatsapp.IWhatsappReplyEvent import IWhatsappReplyEvent
+from nerualpha.webhookEvents.whatsapp.IReplyObject import IReplyObject
+from nerualpha.webhookEvents.whatsapp.IWhatsappReplyEvent import IWhatsappReplyEvent
 
 @dataclass
 class WhatsappReplyEvent(IWhatsappReplyEvent):
